package com.example.siamobile

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import com.example.siamobile.ui.theme.SIAMobileTheme

data class MataKuliah(
    val no: Int,
    val namaMK: String,
    val sem: Int,
    val sks: Int,
)

class Mhs202210715237 : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        val mahasiswaName = intent.getStringExtra("mahasiswaName") ?: "Nama: Sultan Ahmad Rizki Badani\nNPM: 202210715237"
        setContent {
            SIAMobileTheme {
                DetailMahasiswaScreen2(mahasiswaName)
            }
        }
    }
}

@Composable
fun DetailMahasiswaScreen2(mahasiswaName: String) {
    val context = LocalContext.current

    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
        verticalArrangement = Arrangement.SpaceBetween
    ) {
        Column {
            Text(
                text = "KHS Mahasiswa",
                style = MaterialTheme.typography.headlineMedium,
                fontWeight = FontWeight.Bold
            )
            Spacer(modifier = Modifier.height(8.dp))
            Text(
                text = mahasiswaName,
                style = MaterialTheme.typography.bodyLarge,
                fontWeight = FontWeight.Medium
            )
            Spacer(modifier = Modifier.height(16.dp))
            TabelMataKuliah() // Menambahkan tabel mata kuliah
        }

        Button(
            onClick = { (context as? ComponentActivity)?.finish() },
            modifier = Modifier
                .align(Alignment.CenterHorizontally)
                .padding(top = 16.dp)
                .fillMaxWidth()
        ) {
            Text(text = "Kembali")
        }
    }
}

@Composable
fun TabelMataKuliah() {
    val mataKuliahList = listOf(
        MataKuliah(1, "Aljabar Linear", 1, 3),
        MataKuliah(2, "Character Building", 1, 2),
        MataKuliah(3, "Dasar Pemrograman", 1, 2),
        MataKuliah(4, "Fisika", 1, 3),
        MataKuliah(5, "Kalkulus 1", 1, 3),
        MataKuliah(6, "Kewarganegaraan", 1, 2),
        MataKuliah(7, "Pendidikan Agama", 1, 2),
        MataKuliah(8, "Pengantar Teknologi Informasi", 1, 2),
        MataKuliah(9, "Struktur Data dan Algoritma", 1, 3),
        MataKuliah(10, "Bahasa Indonesia", 2, 2),
        MataKuliah(11, "Desain dan Analisis Algoritma", 2, 2),
        MataKuliah(12, "Kalkulus II", 2, 3),
        MataKuliah(13, "Logika Matematika", 2, 3),
        MataKuliah(14, "Matematika Diskrit", 2, 3),
        MataKuliah(15, "Sistem Basis Data", 2, 3),
    )

    Column(modifier = Modifier.fillMaxWidth()) {
        // Header Tabel
        Row(
            modifier = Modifier
                .fillMaxWidth()
                .padding(8.dp)
                .background(MaterialTheme.colorScheme.primary), // Menggunakan warna dari tema Material
            verticalAlignment = Alignment.CenterVertically
        ) {
            Text("No", modifier = Modifier.weight(0.1f), fontWeight = FontWeight.Bold, color = Color.White)
            Text("Mata Kuliah", modifier = Modifier.weight(0.4f), fontWeight = FontWeight.Bold, color = Color.White)
            Text("Sem", modifier = Modifier.weight(0.1f), fontWeight = FontWeight.Bold, color = Color.White)
            Text("SKS", modifier = Modifier.weight(0.1f), fontWeight = FontWeight.Bold, color = Color.White)
        }

        // Data Tabel
        LazyColumn {
            items(mataKuliahList) { mataKuliah ->
                Row(
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(8.dp),
                    verticalAlignment = Alignment.CenterVertically
                ) {
                    Text(mataKuliah.no.toString(), modifier = Modifier.weight(0.1f))
                    Text(mataKuliah.namaMK, modifier = Modifier.weight(0.4f))
                    Text(mataKuliah.sem.toString(), modifier = Modifier.weight(0.1f))
                    Text(mataKuliah.sks.toString(), modifier = Modifier.weight(0.1f))
                }
            }
        }
    }
}
